# Plugin Name

## 简介

这是一个 NcatBot 插件模板。

## 功能

- 群消息事件处理
- 好友消息事件处理
- 测试功能 (/test)

## 使用方法

1. 在群聊中发送 "测试" 消息
2. 在私聊中发送 "测试" 消息
3. 使用 `/test` 命令测试功能

## 配置项

- `greeting`: 问候语，默认值为 "你好"，可选值: ["你好", "Hello", "Hi"]

## 依赖

- NcatBot >= 3.0.0

## 作者

Your Name

## 许可证

MIT
